@@ -93,7 +93,7 @@ class Exceptions:
 
 class CodeArtifactClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html)
     """
 
@@ -106,12 +106,12 @@ class CodeArtifactClient(BaseClient):
         """
 
     def associate_external_connection(
-        self, *, domain: str, repository: str, externalConnection: str, domainOwner: str = None
+        self, *, domain: str, repository: str, externalConnection: str, domainOwner: str = ...
     ) -> AssociateExternalConnectionResultTypeDef:
         """
         Adds an existing external connection to a repository.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.associate_external_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Client.associate_external_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#associate_external_connection)
         """
 
@@ -119,7 +119,7 @@ class CodeArtifactClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#can_paginate)
         """
 
@@ -131,28 +131,28 @@ class CodeArtifactClient(BaseClient):
         destinationRepository: str,
         format: PackageFormatType,
         package: str,
-        domainOwner: str = None,
-        namespace: str = None,
-        versions: Sequence[str] = None,
-        versionRevisions: Mapping[str, str] = None,
-        allowOverwrite: bool = None,
-        includeFromUpstream: bool = None
+        domainOwner: str = ...,
+        namespace: str = ...,
+        versions: Sequence[str] = ...,
+        versionRevisions: Mapping[str, str] = ...,
+        allowOverwrite: bool = ...,
+        includeFromUpstream: bool = ...
     ) -> CopyPackageVersionsResultTypeDef:
         """
         Copies package versions from one repository to another repository in the same
         domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.copy_package_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Client.copy_package_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#copy_package_versions)
         """
 
     def create_domain(
-        self, *, domain: str, encryptionKey: str = None, tags: Sequence["TagTypeDef"] = None
+        self, *, domain: str, encryptionKey: str = ..., tags: Sequence["TagTypeDef"] = ...
     ) -> CreateDomainResultTypeDef:
         """
         Creates a domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.create_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Client.create_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#create_domain)
         """
 
@@ -161,33 +161,33 @@ class CodeArtifactClient(BaseClient):
         *,
         domain: str,
         repository: str,
-        domainOwner: str = None,
-        description: str = None,
-        upstreams: Sequence["UpstreamRepositoryTypeDef"] = None,
-        tags: Sequence["TagTypeDef"] = None
+        domainOwner: str = ...,
+        description: str = ...,
+        upstreams: Sequence["UpstreamRepositoryTypeDef"] = ...,
+        tags: Sequence["TagTypeDef"] = ...
     ) -> CreateRepositoryResultTypeDef:
         """
         Creates a repository.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.create_repository)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Client.create_repository)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#create_repository)
         """
 
-    def delete_domain(self, *, domain: str, domainOwner: str = None) -> DeleteDomainResultTypeDef:
+    def delete_domain(self, *, domain: str, domainOwner: str = ...) -> DeleteDomainResultTypeDef:
         """
         Deletes a domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.delete_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Client.delete_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#delete_domain)
         """
 
     def delete_domain_permissions_policy(
-        self, *, domain: str, domainOwner: str = None, policyRevision: str = None
+        self, *, domain: str, domainOwner: str = ..., policyRevision: str = ...
     ) -> DeleteDomainPermissionsPolicyResultTypeDef:
         """
         Deletes the resource policy set on a domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.delete_domain_permissions_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Client.delete_domain_permissions_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#delete_domain_permissions_policy)
         """
 
@@ -199,46 +199,46 @@ class CodeArtifactClient(BaseClient):
         format: PackageFormatType,
         package: str,
         versions: Sequence[str],
-        domainOwner: str = None,
-        namespace: str = None,
-        expectedStatus: PackageVersionStatusType = None
+        domainOwner: str = ...,
+        namespace: str = ...,
+        expectedStatus: PackageVersionStatusType = ...
     ) -> DeletePackageVersionsResultTypeDef:
         """
         Deletes one or more versions of a package.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.delete_package_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Client.delete_package_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#delete_package_versions)
         """
 
     def delete_repository(
-        self, *, domain: str, repository: str, domainOwner: str = None
+        self, *, domain: str, repository: str, domainOwner: str = ...
     ) -> DeleteRepositoryResultTypeDef:
         """
         Deletes a repository.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.delete_repository)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Client.delete_repository)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#delete_repository)
         """
 
     def delete_repository_permissions_policy(
-        self, *, domain: str, repository: str, domainOwner: str = None, policyRevision: str = None
+        self, *, domain: str, repository: str, domainOwner: str = ..., policyRevision: str = ...
     ) -> DeleteRepositoryPermissionsPolicyResultTypeDef:
         """
         Deletes the resource policy that is set on a repository.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.delete_repository_permissions_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Client.delete_repository_permissions_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#delete_repository_permissions_policy)
         """
 
     def describe_domain(
-        self, *, domain: str, domainOwner: str = None
+        self, *, domain: str, domainOwner: str = ...
     ) -> DescribeDomainResultTypeDef:
         """
         Returns a `DomainDescription <https://docs.aws.amazon.com/codeartifact/latest/AP
         IReference/API_DomainDescription.html>`__ object that contains information about
         the requested domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.describe_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Client.describe_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#describe_domain)
         """
 
@@ -250,36 +250,36 @@ class CodeArtifactClient(BaseClient):
         format: PackageFormatType,
         package: str,
         packageVersion: str,
-        domainOwner: str = None,
-        namespace: str = None
+        domainOwner: str = ...,
+        namespace: str = ...
     ) -> DescribePackageVersionResultTypeDef:
         """
         Returns a `PackageVersionDescription <https://docs.aws.amazon.com/codeartifact/l
         atest/APIReference/API_PackageVersionDescription.html>`__ object that contains
         information about the requested package version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.describe_package_version)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Client.describe_package_version)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#describe_package_version)
         """
 
     def describe_repository(
-        self, *, domain: str, repository: str, domainOwner: str = None
+        self, *, domain: str, repository: str, domainOwner: str = ...
     ) -> DescribeRepositoryResultTypeDef:
         """
         Returns a `RepositoryDescription` object that contains detailed information
         about the requested repository.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.describe_repository)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Client.describe_repository)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#describe_repository)
         """
 
     def disassociate_external_connection(
-        self, *, domain: str, repository: str, externalConnection: str, domainOwner: str = None
+        self, *, domain: str, repository: str, externalConnection: str, domainOwner: str = ...
     ) -> DisassociateExternalConnectionResultTypeDef:
         """
         Removes an existing external connection from a repository.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.disassociate_external_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Client.disassociate_external_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#disassociate_external_connection)
         """
 
@@ -291,51 +291,51 @@ class CodeArtifactClient(BaseClient):
         format: PackageFormatType,
         package: str,
         versions: Sequence[str],
-        domainOwner: str = None,
-        namespace: str = None,
-        versionRevisions: Mapping[str, str] = None,
-        expectedStatus: PackageVersionStatusType = None
+        domainOwner: str = ...,
+        namespace: str = ...,
+        versionRevisions: Mapping[str, str] = ...,
+        expectedStatus: PackageVersionStatusType = ...
     ) -> DisposePackageVersionsResultTypeDef:
         """
         Deletes the assets in package versions and sets the package versions' status to
         `Disposed`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.dispose_package_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Client.dispose_package_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#dispose_package_versions)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#generate_presigned_url)
         """
 
     def get_authorization_token(
-        self, *, domain: str, domainOwner: str = None, durationSeconds: int = None
+        self, *, domain: str, domainOwner: str = ..., durationSeconds: int = ...
     ) -> GetAuthorizationTokenResultTypeDef:
         """
         Generates a temporary authorization token for accessing repositories in the
         domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.get_authorization_token)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Client.get_authorization_token)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#get_authorization_token)
         """
 
     def get_domain_permissions_policy(
-        self, *, domain: str, domainOwner: str = None
+        self, *, domain: str, domainOwner: str = ...
     ) -> GetDomainPermissionsPolicyResultTypeDef:
         """
         Returns the resource policy attached to the specified domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.get_domain_permissions_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Client.get_domain_permissions_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#get_domain_permissions_policy)
         """
 
@@ -348,14 +348,14 @@ class CodeArtifactClient(BaseClient):
         package: str,
         packageVersion: str,
         asset: str,
-        domainOwner: str = None,
-        namespace: str = None,
-        packageVersionRevision: str = None
+        domainOwner: str = ...,
+        namespace: str = ...,
+        packageVersionRevision: str = ...
     ) -> GetPackageVersionAssetResultTypeDef:
         """
         Returns an asset (or file) that is in a package.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.get_package_version_asset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Client.get_package_version_asset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#get_package_version_asset)
         """
 
@@ -367,45 +367,45 @@ class CodeArtifactClient(BaseClient):
         format: PackageFormatType,
         package: str,
         packageVersion: str,
-        domainOwner: str = None,
-        namespace: str = None
+        domainOwner: str = ...,
+        namespace: str = ...
     ) -> GetPackageVersionReadmeResultTypeDef:
         """
         Gets the readme file or descriptive text for a package version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.get_package_version_readme)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Client.get_package_version_readme)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#get_package_version_readme)
         """
 
     def get_repository_endpoint(
-        self, *, domain: str, repository: str, format: PackageFormatType, domainOwner: str = None
+        self, *, domain: str, repository: str, format: PackageFormatType, domainOwner: str = ...
     ) -> GetRepositoryEndpointResultTypeDef:
         """
         Returns the endpoint of a repository for a specific package format.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.get_repository_endpoint)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Client.get_repository_endpoint)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#get_repository_endpoint)
         """
 
     def get_repository_permissions_policy(
-        self, *, domain: str, repository: str, domainOwner: str = None
+        self, *, domain: str, repository: str, domainOwner: str = ...
     ) -> GetRepositoryPermissionsPolicyResultTypeDef:
         """
         Returns the resource policy that is set on a repository.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.get_repository_permissions_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Client.get_repository_permissions_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#get_repository_permissions_policy)
         """
 
     def list_domains(
-        self, *, maxResults: int = None, nextToken: str = None
+        self, *, maxResults: int = ..., nextToken: str = ...
     ) -> ListDomainsResultTypeDef:
         """
         Returns a list of `DomainSummary <https://docs.aws.amazon.com/codeartifact/lates
         t/APIReference/API_PackageVersionDescription.html>`__ objects for all domains
         owned by the AWS account that makes this call.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.list_domains)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Client.list_domains)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#list_domains)
         """
 
@@ -417,16 +417,16 @@ class CodeArtifactClient(BaseClient):
         format: PackageFormatType,
         package: str,
         packageVersion: str,
-        domainOwner: str = None,
-        namespace: str = None,
-        maxResults: int = None,
-        nextToken: str = None
+        domainOwner: str = ...,
+        namespace: str = ...,
+        maxResults: int = ...,
+        nextToken: str = ...
     ) -> ListPackageVersionAssetsResultTypeDef:
         """
         Returns a list of `AssetSummary <https://docs.aws.amazon.com/codeartifact/latest
         /APIReference/API_AssetSummary.html>`__ objects for assets in a package version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.list_package_version_assets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Client.list_package_version_assets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#list_package_version_assets)
         """
 
@@ -438,14 +438,14 @@ class CodeArtifactClient(BaseClient):
         format: PackageFormatType,
         package: str,
         packageVersion: str,
-        domainOwner: str = None,
-        namespace: str = None,
-        nextToken: str = None
+        domainOwner: str = ...,
+        namespace: str = ...,
+        nextToken: str = ...
     ) -> ListPackageVersionDependenciesResultTypeDef:
         """
         Returns the direct dependencies for a package version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.list_package_version_dependencies)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Client.list_package_version_dependencies)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#list_package_version_dependencies)
         """
 
@@ -456,19 +456,19 @@ class CodeArtifactClient(BaseClient):
         repository: str,
         format: PackageFormatType,
         package: str,
-        domainOwner: str = None,
-        namespace: str = None,
-        status: PackageVersionStatusType = None,
-        sortBy: Literal["PUBLISHED_TIME"] = None,
-        maxResults: int = None,
-        nextToken: str = None
+        domainOwner: str = ...,
+        namespace: str = ...,
+        status: PackageVersionStatusType = ...,
+        sortBy: Literal["PUBLISHED_TIME"] = ...,
+        maxResults: int = ...,
+        nextToken: str = ...
     ) -> ListPackageVersionsResultTypeDef:
         """
         Returns a list of `PackageVersionSummary <https://docs.aws.amazon.com/codeartifa
         ct/latest/APIReference/API_PackageVersionSummary.html>`__ objects for package
         versions in a repository that match the request parameters.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.list_package_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Client.list_package_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#list_package_versions)
         """
 
@@ -477,30 +477,30 @@ class CodeArtifactClient(BaseClient):
         *,
         domain: str,
         repository: str,
-        domainOwner: str = None,
-        format: PackageFormatType = None,
-        namespace: str = None,
-        packagePrefix: str = None,
-        maxResults: int = None,
-        nextToken: str = None
+        domainOwner: str = ...,
+        format: PackageFormatType = ...,
+        namespace: str = ...,
+        packagePrefix: str = ...,
+        maxResults: int = ...,
+        nextToken: str = ...
     ) -> ListPackagesResultTypeDef:
         """
         Returns a list of `PackageSummary <https://docs.aws.amazon.com/codeartifact/late
         st/APIReference/API_PackageSummary.html>`__ objects for packages in a repository
         that match the request parameters.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.list_packages)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Client.list_packages)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#list_packages)
         """
 
     def list_repositories(
-        self, *, repositoryPrefix: str = None, maxResults: int = None, nextToken: str = None
+        self, *, repositoryPrefix: str = ..., maxResults: int = ..., nextToken: str = ...
     ) -> ListRepositoriesResultTypeDef:
         """
         Returns a list of `RepositorySummary <https://docs.aws.amazon.com/codeartifact/l
         atest/APIReference/API_RepositorySummary.html>`__ objects.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.list_repositories)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Client.list_repositories)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#list_repositories)
         """
 
@@ -508,17 +508,17 @@ class CodeArtifactClient(BaseClient):
         self,
         *,
         domain: str,
-        domainOwner: str = None,
-        administratorAccount: str = None,
-        repositoryPrefix: str = None,
-        maxResults: int = None,
-        nextToken: str = None
+        domainOwner: str = ...,
+        administratorAccount: str = ...,
+        repositoryPrefix: str = ...,
+        maxResults: int = ...,
+        nextToken: str = ...
     ) -> ListRepositoriesInDomainResultTypeDef:
         """
         Returns a list of `RepositorySummary <https://docs.aws.amazon.com/codeartifact/l
         atest/APIReference/API_RepositorySummary.html>`__ objects.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.list_repositories_in_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Client.list_repositories_in_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#list_repositories_in_domain)
         """
 
@@ -527,22 +527,17 @@ class CodeArtifactClient(BaseClient):
         Gets information about AWS tags for a specified Amazon Resource Name (ARN) in
         AWS CodeArtifact.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#list_tags_for_resource)
         """
 
     def put_domain_permissions_policy(
-        self,
-        *,
-        domain: str,
-        policyDocument: str,
-        domainOwner: str = None,
-        policyRevision: str = None
+        self, *, domain: str, policyDocument: str, domainOwner: str = ..., policyRevision: str = ...
     ) -> PutDomainPermissionsPolicyResultTypeDef:
         """
         Sets a resource policy on a domain that specifies permissions to access it.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.put_domain_permissions_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Client.put_domain_permissions_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#put_domain_permissions_policy)
         """
 
@@ -552,14 +547,14 @@ class CodeArtifactClient(BaseClient):
         domain: str,
         repository: str,
         policyDocument: str,
-        domainOwner: str = None,
-        policyRevision: str = None
+        domainOwner: str = ...,
+        policyRevision: str = ...
     ) -> PutRepositoryPermissionsPolicyResultTypeDef:
         """
         Sets the resource policy on a repository that specifies permissions to access
         it.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.put_repository_permissions_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Client.put_repository_permissions_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#put_repository_permissions_policy)
         """
 
@@ -567,7 +562,7 @@ class CodeArtifactClient(BaseClient):
         """
         Adds or updates tags for a resource in AWS CodeArtifact.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#tag_resource)
         """
 
@@ -575,7 +570,7 @@ class CodeArtifactClient(BaseClient):
         """
         Removes tags from a resource in AWS CodeArtifact.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#untag_resource)
         """
 
@@ -588,15 +583,15 @@ class CodeArtifactClient(BaseClient):
         package: str,
         versions: Sequence[str],
         targetStatus: PackageVersionStatusType,
-        domainOwner: str = None,
-        namespace: str = None,
-        versionRevisions: Mapping[str, str] = None,
-        expectedStatus: PackageVersionStatusType = None
+        domainOwner: str = ...,
+        namespace: str = ...,
+        versionRevisions: Mapping[str, str] = ...,
+        expectedStatus: PackageVersionStatusType = ...
     ) -> UpdatePackageVersionsStatusResultTypeDef:
         """
         Updates the status of one or more versions of a package.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.update_package_versions_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Client.update_package_versions_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#update_package_versions_status)
         """
 
@@ -605,21 +600,21 @@ class CodeArtifactClient(BaseClient):
         *,
         domain: str,
         repository: str,
-        domainOwner: str = None,
-        description: str = None,
-        upstreams: Sequence["UpstreamRepositoryTypeDef"] = None
+        domainOwner: str = ...,
+        description: str = ...,
+        upstreams: Sequence["UpstreamRepositoryTypeDef"] = ...
     ) -> UpdateRepositoryResultTypeDef:
         """
         Update the properties of a repository.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.update_repository)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Client.update_repository)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#update_repository)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_domains"]) -> ListDomainsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Paginator.ListDomains)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Paginator.ListDomains)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/paginators.html#listdomainspaginator)
         """
 
@@ -628,7 +623,7 @@ class CodeArtifactClient(BaseClient):
         self, operation_name: Literal["list_package_version_assets"]
     ) -> ListPackageVersionAssetsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Paginator.ListPackageVersionAssets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Paginator.ListPackageVersionAssets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/paginators.html#listpackageversionassetspaginator)
         """
 
@@ -637,14 +632,14 @@ class CodeArtifactClient(BaseClient):
         self, operation_name: Literal["list_package_versions"]
     ) -> ListPackageVersionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Paginator.ListPackageVersions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Paginator.ListPackageVersions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/paginators.html#listpackageversionspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_packages"]) -> ListPackagesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Paginator.ListPackages)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Paginator.ListPackages)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/paginators.html#listpackagespaginator)
         """
 
@@ -653,7 +648,7 @@ class CodeArtifactClient(BaseClient):
         self, operation_name: Literal["list_repositories"]
     ) -> ListRepositoriesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Paginator.ListRepositories)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Paginator.ListRepositories)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/paginators.html#listrepositoriespaginator)
         """
 
@@ -662,6 +657,6 @@ class CodeArtifactClient(BaseClient):
         self, operation_name: Literal["list_repositories_in_domain"]
     ) -> ListRepositoriesInDomainPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Paginator.ListRepositoriesInDomain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codeartifact.html#CodeArtifact.Paginator.ListRepositoriesInDomain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/paginators.html#listrepositoriesindomainpaginator)
         """
